@@ -21,7 +21,7 @@ Provides XML I{element} classes.
 from logging import getLogger
 from suds import *
 from suds.sax import *
-from suds.sax.text import Text, Pickler
+from suds.sax.text import Text
 from suds.sax.attribute import Attribute
 import sys 
 if sys.version_info < (2, 4, 0): 
@@ -820,12 +820,24 @@ class Element:
         @return: A flat list of nodes.
         @rtype: [L{Element},..]
         """
-        branch = []
+        branch = [self]
         for c in self.children:
-            branch.append(c)
             branch += c.branch()
         return branch
     
+    def ancestors(self):
+        """
+        Get a list of ancestors.
+        @return: A list of ancestors.
+        @rtype: [L{Element},..]
+        """
+        ancestors = []
+        p = self.parent
+        while p is not None:
+            ancestors.append(p)
+            p = p.parent
+        return ancestors
+    
     def walk(self, visitor):
         """
         Walk the branch and call the visitor function
@@ -895,15 +907,6 @@ class Element:
             if index < len(self.children) and \
                 isinstance(value, Element):
                 self.children.insert(index, value)
-                
-    def __getstate__(self):
-        state = self.__dict__.copy()
-        state['text'] = Pickler.dump(self.text)
-        return state
-    
-    def __setstate__(self, state):
-        self.__dict__.update(state)
-        self.text = Pickler.load(self.text)
 
     def __eq__(self, rhs):
         return  rhs is not None and \
@@ -964,7 +967,7 @@ class PrefixNormalizer:
         @rtype: set
         """
         s = set()
-        for n in self.branch:
+        for n in self.branch + self.node.ancestors():
             if self.permit(n.expns):
                 s.add(n.expns)
             s = s.union(self.pset(n))
